==> mapguide-1.0.1.tar.gz: mapguide-1.0.1/Common/MdfModel/AreaTypeStyle.h <==
//
//  Copyright (C) 2004-2006  Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#ifndef AREATYPESTYLE_H_
#define AREATYPESTYLE_H_

#include "FeatureTypeStyle.h"

BEGIN_NAMESPACE_MDFMODEL

    //-------------------------------------------------------------------------
    // DESCRIPTION:
    // The AreaTypeStyle class is a FeatureTypeStyle for geometric
    // primitives of type polygon. It contains a collection of AreaRules
    // that are processed in order. If the AreaRule's Filter evaluates to True,
    // the Rule can contribute to the Symbolization that this AreaTypeStyle
    // defines.
    //-------------------------------------------------------------------------
    class MDFMODEL_API AreaTypeStyle : public FeatureTypeStyle
    {
    public:
        // Construction, destruction, initialization
        AreaTypeStyle();
        virtual ~AreaTypeStyle();

        // Implementation of FeatureTypeStyle Visitor pattern method.
        virtual void AcceptVisitor(IFeatureTypeStyleVisitor& ivtsvVisitor);

    private:
        // Hidden copy constructor and assignment operator.
        AreaTypeStyle(const AreaTypeStyle&);
        AreaTypeStyle& operator=(const AreaTypeStyle&);
    };

END_NAMESPACE_MDFMODEL
#endif // AREATYPESTYLE_H_

==> mapguide-1.2.0.tar.gz: mapguide-1.2.0/Common/MdfModel/AreaTypeStyle.h <==
//
//  Copyright (C) 2004-2007 by Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#ifndef AREATYPESTYLE_H_
#define AREATYPESTYLE_H_

#include "FeatureTypeStyle.h"

BEGIN_NAMESPACE_MDFMODEL

    //-------------------------------------------------------------------------
    // DESCRIPTION:
    // The AreaTypeStyle class is a FeatureTypeStyle for geometric
    // primitives of type polygon. It contains a collection of AreaRules
    // that are processed in order. If the AreaRule's Filter evaluates to True,
    // the Rule can contribute to the Symbolization that this AreaTypeStyle
    // defines.
    //-------------------------------------------------------------------------
    class MDFMODEL_API AreaTypeStyle : public FeatureTypeStyle
    {
    public:
        // Construction, destruction, initialization
        AreaTypeStyle();
        virtual ~AreaTypeStyle();

        // Implementation of FeatureTypeStyle Visitor pattern method.
        virtual void AcceptVisitor(IFeatureTypeStyleVisitor& iftsVisitor);

    private:
        // Hidden copy constructor and assignment operator.
        AreaTypeStyle(const AreaTypeStyle&);
        AreaTypeStyle& operator=(const AreaTypeStyle&);
    };

END_NAMESPACE_MDFMODEL
#endif // AREATYPESTYLE_H_
